import { useState } from 'react';
import AddTodo from './components/AddTodo';
import Header from './components/Header';
import Todos from './components/Todos';

function App() {

  const [showAddTask, setShowAddTask] = useState(false)
  const [todos, setTodos] = useState([
    {
      id: 1,
      text: 'Todo 1',
      day: '28th Feb at 1.05pm',
      reminder: true
    },
    {
      id: 2,
      text: 'Todo 2',
      day: '27th Jan at 1.06pm',
      reminder: false
    },
    {
      id: 3,
      text: 'Todo 3',
      day: '13th Mar at 1.07pm',
      reminder: true
    },
  ])

  // Delete Todos
  const deleteTodo = (id) => {
    console.log('delete', id)
    setTodos(todos.filter((todo) => todo.id != id))
  }

  // Toggle Reminder
  const toggleReminder = (id) => {
    setTodos(
      todos.map((todo) =>
        todo.id === id ? { ...todo, reminder: !todo.reminder } : todo
      )
    )
  }

  // Add Todo
  const addTodo = (todo) => {
    const id = Math.floor(Math.random() * 10000) + 1
    const newTodo = { id, ...todo }
    setTodos([...todos, newTodo])
  }

  return (
    <div className="container">
      <Header onShow={() => setShowAddTask(!showAddTask)} onChangeText={showAddTask}/>
      {showAddTask && <AddTodo onAdd={addTodo} />}
      {
        todos.length > 0 ?
          (<Todos todos={todos} onDelete={deleteTodo} onToggle={toggleReminder} />)
          : 'No Todos To Show'
      }
    </div>
  );
}

export default App;
